<!-- markdownlint-disable -->

<a href="..\..\qtstrap\settings.py#L0"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

# <kbd>module</kbd> `settings`





---

<a href="..\..\qtstrap\settings.py#L4"><img align="right" style="float:right;" src="https://img.shields.io/badge/-source-cccccc?style=flat-square"></a>

## <kbd>function</kbd> `uncache`

```python
uncache(exclude)
```

Remove package modules from cache except excluded ones. On next import they will be reloaded. 



**Args:**
 
 - <b>`exclude`</b> (iter<str>):  Sequence of module paths. 




---

_This file was automatically generated via [lazydocs](https://github.com/ml-tooling/lazydocs)._
